// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef INCIDENCEEDITOR_VERSION_H
#define INCIDENCEEDITOR_VERSION_H

#define INCIDENCEEDITOR_VERSION_STRING "6.6.3"
#define INCIDENCEEDITOR_VERSION_MAJOR 6
#define INCIDENCEEDITOR_VERSION_MINOR 6
#define INCIDENCEEDITOR_VERSION_PATCH 3
#define INCIDENCEEDITOR_VERSION ((6<<16)|(6<<8)|(3))

#endif
